summaryrefslogtreecommitdiff
path: root/tikzit/src/gtk/EdgeStyleSelector.h
diff options
context:
space:
mode:
Diffstat (limited to 'tikzit/src/gtk/EdgeStyleSelector.h')
-rw-r--r--tikzit/src/gtk/EdgeStyleSelector.h26
1 files changed, 14 insertions, 12 deletions
diff --git a/tikzit/src/gtk/EdgeStyleSelector.h b/tikzit/src/gtk/EdgeStyleSelector.h
index 1ae1f3c..904bd93 100644
--- a/tikzit/src/gtk/EdgeStyleSelector.h
+++ b/tikzit/src/gtk/EdgeStyleSelector.h
@@ -17,25 +17,27 @@
#import "TZFoundation.h"
#import <gtk/gtk.h>
-#import "StyleManager.h"
+
+@class EdgeStyle;
+@class EdgeStylesModel;
+@class StyleManager;
@interface EdgeStyleSelector: NSObject {
- GtkListStore *store;
+ EdgeStylesModel *model;
GtkTreeView *view;
- StyleManager *styleManager;
}
/*!
@property widget
@brief The GTK widget
*/
-@property (readonly) GtkWidget *widget;
+@property (readonly) GtkWidget *widget;
/*!
- @property manager
- @brief The StyleManager to use. Default is [StyleManager manager]
+ @property model
+ @brief The model to use.
*/
-@property (retain) StyleManager *styleManager;
+@property (retain) EdgeStylesModel *model;
/*!
@property selectedStyle
@@ -43,16 +45,16 @@
When this changes, a SelectedStyleChanged notification will be posted
*/
-@property (assign) EdgeStyle *selectedStyle;
+@property (assign) EdgeStyle *selectedStyle;
/*!
* Initialise with the default style manager
*/
-- (id) init;
+- (id) initWithStyleManager:(StyleManager*)m;
/*!
* Initialise with the given style manager
*/
-- (id) initWithStyleManager:(StyleManager*)m;
+- (id) initWithModel:(EdgeStylesModel*)model;
@end
@@ -43,16 +45,16 @@
/*!
- * Initialise with the default style manager
+ * Initialise with a new model for the given style manager
*/
@@ -43,16 +45,16 @@
/*!
- * Initialise with the given style manager
+ * Initialise with the given model
*/